@@ -1,6 +1,6 @@
 # coding=utf-8
 
-#    Copyright (C) 2008-2011 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2008-2012 Luis Falcon <lfalcon@gnusolidario.org>
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -36,8 +36,8 @@ class DrugDoseUnits(ModelSQL, ModelView):
     _description = __doc__
 
     _name = "gnuhealth.dose.unit"
-    name = fields.Char('Unit', required=True, select=True)
-    desc = fields.Char('Description')
+    name = fields.Char('Unit', required=True, select=True, translate=True)
+    desc = fields.Char('Description', translate=True)
 
     def __init__(self):
         super(DrugDoseUnits, self).__init__()
@@ -53,7 +53,7 @@ class MedicationFrequency(ModelSQL, ModelView):
     _description = __doc__
 
     _name = "gnuhealth.medication.dosage"
-    name = fields.Char('Frequency', required=True, select=True,
+    name = fields.Char('Frequency', required=True, select=True, translate=True,
         help='Common frequency name')
     code = fields.Char('Code',
         help='Dosage Code,for example: SNOMED 229798009 = 3 times per day')
@@ -74,7 +74,7 @@ class DrugForm(ModelSQL, ModelView):
     _description = __doc__
 
     _name = "gnuhealth.drug.form"
-    name = fields.Char('Form', required=True, select=True)
+    name = fields.Char('Form', required=True, select=True, translate=True)
     code = fields.Char('Code')
 
     def __init__(self):
@@ -91,7 +91,7 @@ class DrugRoute(ModelSQL, ModelView):
     _description = __doc__
 
     _name = "gnuhealth.drug.route"
-    name = fields.Char('Unit', required=True, select=True)
+    name = fields.Char('Unit', required=True, select=True, translate=True)
     code = fields.Char('Code')
 
     def __init__(self):
@@ -108,7 +108,7 @@ class Occupation(ModelSQL, ModelView):
     _description = __doc__
 
     _name = "gnuhealth.occupation"
-    name = fields.Char('Name', required="1")
+    name = fields.Char('Name', required="1", translate=True)
     code = fields.Char('Code')
 
     def __init__(self):
@@ -125,7 +125,7 @@ class Ethnicity(ModelSQL, ModelView):
     _description = __doc__
 
     _name = "gnuhealth.ethnicity"
-    name = fields.Char('Name', required="1")
+    name = fields.Char('Name', required="1", translate=True)
     code = fields.Char('Code')
     notes = fields.Char('Notes')
 
@@ -143,9 +143,9 @@ class MedicalSpecialty(ModelSQL, ModelView):
     _description = __doc__
 
     _name = "gnuhealth.specialty"
-    name = fields.Char('Specialty', required="1", select="1",
+    name = fields.Char('Specialty', required="1", translate=True,
         help="ie, Addiction Psychiatry")
-    code = fields.Char('Code', select="1", help="ie, ADP")
+    code = fields.Char('Code', help="ie, ADP")
 
     def __init__(self):
         super(MedicalSpecialty, self).__init__()
@@ -162,12 +162,12 @@ class Physician(ModelSQL, ModelView):
     _description = __doc__
 
     name = fields.Many2One('party.party', 'Physician',
-        required="1", domain=[('is_doctor', '=', True)], select="1",
+        required="1", domain=[('is_doctor', '=', True)],
         help="Physician's Name, from the partner list")
     institution = fields.Many2One('party.party', 'Institution',
         domain=[('is_institution', '=', True)],
         help="Instituion where she/he works")
-    code = fields.Char('ID', select="1", help="MD License ID")
+    code = fields.Char('ID', help="MD License ID")
     specialty = fields.Many2One('gnuhealth.specialty',
         'Specialty', help="Specialty Code")
     info = fields.Text('Extra info')
@@ -193,7 +193,7 @@ class OperationalArea (ModelSQL, ModelView):
     _name = "gnuhealth.operational_area"
     _description = __doc__
     name = fields.Char('Name',
-        help="Operational Area of the city or region", required="1", select="1")
+        help="Operational Area of the city or region", required="1")
     operational_sector = fields.One2Many ('gnuhealth.operational_sector','operational_area',
         'Operational Sector',readonly="1")
         
@@ -213,10 +213,10 @@ class OperationalSector(ModelSQL, ModelView):
     _name = "gnuhealth.operational_sector"
     _description = __doc__
 
-    name = fields.Char('Op. Sector', required="1", select="1",
+    name = fields.Char('Op. Sector', required="1",
         help="Region included in an operational area")
     operational_area = fields.Many2One('gnuhealth.operational_area',
-     'Operational Area', select="1")
+     'Operational Area')
     info = fields.Text('Extra Information')
 
     def __init__(self):
@@ -233,10 +233,10 @@ class Family(ModelSQL, ModelView):
     "Family"
     _name = "gnuhealth.family"
 
-    name = fields.Char('Family', required="1", select="1",
+    name = fields.Char('Family', required="1",
      help="Family code within an operational sector")
     operational_sector = fields.Many2One('gnuhealth.operational_sector',
-        'Operational Sector', select="1")
+        'Operational Sector')
     members = fields.One2Many('gnuhealth.family_member', 'name',
         'Family Members')
 
@@ -257,7 +257,7 @@ class FamilyMember(ModelSQL, ModelView):
 
     name = fields.Many2One('gnuhealth.family', 'Family', required="1",
      select="1", help="Family code")
-    party = fields.Many2One('party.party', 'Party', required="1", select="1",
+    party = fields.Many2One('party.party', 'Party', required="1",
         domain=[('is_person', '=', True)], help="Family code")
     role = fields.Char('Role', help="Father, Mother, sibbling...")
 
@@ -312,9 +312,10 @@ class Medicament(ModelSQL, ModelView):
     _name = "gnuhealth.medicament"
 
     name = fields.Many2One('product.product', 'Product',
-        domain=[('is_medicament', '=', True)], select="1",
+        domain=[('is_medicament', '=', True)],
         help="Product Name", required=True)
-    active_component = fields.Char('Active component', help="Active Component")
+    active_component = fields.Char('Active component', help="Active Component",
+        translate=True)
     category = fields.Many2One('gnuhealth.medicament.category', 'Category', select= True)
     therapeutic_action = fields.Char('Therapeutic effect',
         help="Therapeutic action")
@@ -336,7 +337,7 @@ class Medicament(ModelSQL, ModelView):
                         ('X', 'X'),
                         ('N', 'N'),
 
-                        ], 'Pregnancy Category', select="1",
+                        ], 'Pregnancy Category',
                         help='** FDA Pregancy Categories ***\n' \
                         'CATEGORY A :Adequate and well-controlled human studies have' \
                         ' failed to demonstrate a risk to the fetus in the' \
@@ -389,7 +390,7 @@ class PathologyCategory(ModelSQL, ModelView):
     _description = __doc__
     _name = 'gnuhealth.pathology.category'
 
-    name = fields.Char('Category Name', required=True)
+    name = fields.Char('Category Name', required=True, translate=True)
     parent = fields.Many2One('gnuhealth.pathology.category',
      'Parent Category', select=True)
     childs = fields.One2Many('gnuhealth.pathology.category',
@@ -428,8 +429,8 @@ PathologyCategory()
 class Pathology (ModelSQL, ModelView):
     "Diseases"
     _name = "gnuhealth.pathology"
-    name = fields.Char('Name', help="Disease name", required=True, select="1")
-    code = fields.Char('Code', select="1",
+    name = fields.Char('Name', help="Disease name", required=True, translate=True)
+    code = fields.Char('Code',
         help='Specific Code for the Disease (eg, ICD-10, SNOMED...\)')
     category = fields.Many2One('gnuhealth.pathology.category',
         'Disease Category')
@@ -453,8 +454,8 @@ class ProcedureCode(ModelSQL, ModelView):
     _name = "gnuhealth.procedure"
     _description = __doc__
 
-    name = fields.Char('Code', required=True, select="1")
-    description = fields.Char('Long Text', select="1")
+    name = fields.Char('Code', required=True )
+    description = fields.Char('Long Text', translate=True)
 
 ProcedureCode()
 
@@ -466,10 +467,10 @@ class InsurancePlan(ModelSQL, ModelView):
 
     name = fields.Many2One('product.product', 'Plan',
      domain=[('type', '=', "service")],
-      help="Insurance company plan", select="1", required=True)
+      help="Insurance company plan", required=True)
 
     company = fields.Many2One('party.party', 'Insurance Company',
-     domain=[('is_insurance_company', '=', True)], select="1", required=True)
+     domain=[('is_insurance_company', '=', True)], required=True)
 
     is_default = fields.Boolean('Default plan',
         help='Check if this is the default plan when assigning ' \
@@ -535,7 +536,7 @@ class PartyPatient (ModelSQL, ModelView):
     activation_date = fields.Date('Activation date',
      help="Date of activation of the party")
     alias = fields.Char('Alias', help="Common name that the Party is reffered")
-    ref = fields.Char('ID Number', size=64, help="Patient Personal ID")
+    ref = fields.Char('SSN', help="Patient Social Security Number or equivalent")
     is_person = fields.Boolean('Person',
      help="Check if the party is a person.")
     is_patient = fields.Boolean('Patient',
@@ -564,7 +565,7 @@ class PartyPatient (ModelSQL, ModelView):
     def __init__(self):
         super(PartyPatient, self).__init__()
         self._sql_constraints += [
-            ('ref_uniq', 'UNIQUE(ref)', 'The Party ID must be unique')]
+            ('ref_uniq', 'UNIQUE(ref)', 'The Patient SSN must be unique')]
 
     def get_rec_name(self, ids, name):
         if not ids:
@@ -675,14 +676,18 @@ class PatientData(ModelSQL, ModelView):
             patient_data.deceased, patient_data.dod)
         return result
 
-    name = fields.Many2One('party.party', 'Patient', required="1", select="1",
+    name = fields.Many2One('party.party', 'Patient', required="1",
         domain=[('is_patient', '=', True), ('is_person', '=', True)],
         help="Patient Name")
     lastname = fields.Function(fields.Char('Lastname'),
         'get_patient_lastname', searcher="search_patient_lastname")
-    identification_code = fields.Char('ID', readonly=True, select="1",
+
+    ssn = fields.Function(fields.Char('SSN'),
+        'get_patient_ssn', searcher="search_patient_ssn")
+
+    identification_code = fields.Char('ID', readonly=True,
        help='Patient Identifier provided by the Health Center.' \
-        'Is not the ID from the party form')
+        'Is not the Social Security Number')
 
     family = fields.Many2One('gnuhealth.family',
         'Family', help="Family Code")
@@ -750,6 +755,19 @@ class PatientData(ModelSQL, ModelView):
      states={'invisible': Not(Bool(Eval('deceased'))),
       'required': Bool(Eval('deceased'))})
 
+    def get_patient_ssn(self, ids, name):
+        res = {}
+        for patient in self.browse(ids):
+            res[patient.id] = patient.name.ref
+        return res
+
+    def search_patient_ssn(self, name, clause):
+        res = []
+        value = clause[2]
+        res.append(('name.ref', clause[1], value))
+        return res
+
+
     def get_patient_lastname(self, ids, name):
         res = {}
         for patient in self.browse(ids):
@@ -836,8 +854,8 @@ class PatientDiseaseInfo (ModelSQL, ModelView):
     pcs_code = fields.Many2One('gnuhealth.procedure', 'Code',
         help="Procedure code, for example, ICD-10-PCS Code 7-character string")
     treatment_description = fields.Char('Treatment Description')
-    date_start_treatment = fields.Date('Start of treatment')
-    date_stop_treatment = fields.Date('End of treatment')
+    date_start_treatment = fields.Date('Start', help="Start of treatment date")
+    date_stop_treatment = fields.Date('End', help="End of treatment date")
     status = fields.Selection([
         ('a', 'acute'),
         ('c', 'chronic'),
@@ -868,16 +886,16 @@ class Appointment (ModelSQL, ModelView):
     _name = "gnuhealth.appointment"
     _description = __doc__
 
-    name = fields.Char('Appointment ID', readonly=True, select="2")
+    name = fields.Char('Appointment ID', readonly=True)
     doctor = fields.Many2One('gnuhealth.physician', 'Physician',
         select="1", help="Physician's Name")
     patient = fields.Many2One('gnuhealth.patient', 'Patient', required=True,
         select="1", help="Patient Name")
-    appointment_date = fields.DateTime('Date and Time', select="1")
+    appointment_date = fields.DateTime('Date and Time')
     institution = fields.Many2One('party.party', 'Health Center',
         domain=[('is_institution', '=', True)], help="Medical Center")
     speciality = fields.Many2One('gnuhealth.specialty', 'Specialty',
-        select="2", help="Medical Specialty / Sector")
+        help="Medical Specialty / Sector")
     urgency = fields.Selection([
             ('a', 'Normal'),
             ('b', 'Urgent'),
@@ -983,8 +1001,8 @@ class MedicationTemplate(ModelSQL, ModelView):
             ('indefinite', 'indefinite')], 'Treatment period',
             help='Period that the patient must take the medication in ' \
             'minutes, hours, days, months, years or indefinately', sort=False)
-    start_treatment = fields.DateTime('Start of treatment')
-    end_treatment = fields.DateTime('End of treatment')
+    start_treatment = fields.DateTime('Start', help="Date of start of Treatment")
+    end_treatment = fields.DateTime('End', help="Date of start of Treatment")
 
 MedicationTemplate()
 
@@ -1002,16 +1020,47 @@ class PatientMedication(ModelSQL, ModelView):
     doctor = fields.Many2One('gnuhealth.physician', 'Physician',
         help="Physician who prescribed the medicament")
     is_active = fields.Boolean('Active',
-        help="Check if the patient is currently taking the medication")
-    discontinued = fields.Boolean('Discontinued')
-    course_completed = fields.Boolean('Course Completed')
+        help="Check if the patient is currently taking the medication",
+        on_change_with=['discontinued', 'course_completed'])
+    discontinued = fields.Boolean('Discontinued',
+        on_change_with=['is_active', 'course_completed'])
+    course_completed = fields.Boolean('Course Completed',
+        on_change_with=['is_active', 'discontinued'])
     discontinued_reason = fields.Char('Reason for discontinuation',
-        help="Short description for discontinuing the treatment")
+        help="Short description for discontinuing the treatment",
+         states={'invisible': Not(Bool(Eval('discontinued'))),
+         'required': Bool(Eval('discontinued'))})
     adverse_reaction = fields.Text('Adverse Reactions',
         help="Side effects or adverse reactions that the patient experienced")
     notes = fields.Text('Extra Info')
     patient = fields.Many2One('gnuhealth.patient', 'Patient')
 
+    def on_change_with_is_active (self, vals):
+        discontinued = vals.get('discontinued')
+        course_completed = vals.get('course_completed')
+        is_active = True
+        if (discontinued or course_completed):
+            is_active = False
+        return is_active
+
+    def on_change_with_discontinued (self, vals):
+        discontinued = vals.get('discontinued')
+        is_active = vals.get('is_active')
+        course_completed = vals.get('course_completed')
+
+        if (is_active or course_completed):
+                discontinued = False
+        return ( discontinued ) 
+        
+    def on_change_with_course_completed (self, vals):
+        is_active = vals.get('is_active')
+        course_completed = vals.get('discontinued')
+        discontinued = vals.get('discontinued')
+
+        if (is_active or discontinued):
+                course_completed = False
+        return ( course_completed ) 
+
     def default_is_active(self):
         return True
 
@@ -1098,11 +1147,11 @@ class PatientPrescriptionOrder(ModelSQL, ModelView):
     patient = fields.Many2One('gnuhealth.patient', 'Patient', required=True,
      select="1")
     prescription_id = fields.Char('Prescription ID',
-        readonly=True, help='Type in the ID of this prescription', select="2")
-    prescription_date = fields.DateTime('Prescription Date', select="1")
+        readonly=True, help='Type in the ID of this prescription')
+    prescription_date = fields.DateTime('Prescription Date')
     user_id = fields.Many2One('res.user', 'Prescribing Doctor', readonly=True,
      select="1")
-    pharmacy = fields.Many2One('party.party', 'Pharmacy', select="2")
+    pharmacy = fields.Many2One('party.party', 'Pharmacy')
     prescription_line = fields.One2Many('gnuhealth.prescription.line',
         'name', 'Prescription line')
     notes = fields.Text('Prescription Notes')
@@ -1184,12 +1233,12 @@ class PatientEvaluation(ModelSQL, ModelView):
     _name = "gnuhealth.patient.evaluation"
     _description = __doc__
 
-    patient = fields.Many2One('gnuhealth.patient', 'Patient', select="1")
-    evaluation_date = fields.Many2One('gnuhealth.appointment', 'Appointment', select="1", 
+    patient = fields.Many2One('gnuhealth.patient', 'Patient')
+    evaluation_date = fields.Many2One('gnuhealth.appointment', 'Appointment', 
         help='Enter or select the date / ID of the appointment' \
         ' related to this evaluation')
     evaluation_start = fields.DateTime('Start of Evaluation',
-     required=True, select="1")
+     required=True)
     evaluation_endtime = fields.DateTime('End of Evaluation', required="1")
     next_evaluation = fields.Many2One('gnuhealth.appointment',
         'Next Appointment')
@@ -1397,7 +1446,7 @@ class PatientEvaluation(ModelSQL, ModelView):
         'Presumptive Diagnosis', help="Presumptive Diagnosis")
     info_diagnosis = fields.Text('Presumptive Diagnosis: Extra Info')
     directions = fields.Text('Plan')
-    actions = fields.One2Many('gnuhealth.directions', 'name', 'P')
+    actions = fields.One2Many('gnuhealth.directions', 'name', 'Procedures', help="Procedures / Actions to take")
     symptom_pain = fields.Boolean('Pain')
     symptom_pain_intensity = fields.Integer('Pain intensity',
         help="Pain intensity from 0(no pain) to 10(worst possible pain)")
@@ -1510,12 +1559,12 @@ class HospitalBuilding(ModelSQL, ModelView):
     "Hospital Building"
     _description = __doc__
     _name = "gnuhealth.hospital.building"
-    name = fields.Char('Name', select="1", required=True,
+    name = fields.Char('Name', required=True,
         help="Name of the building within the institution")
     institution = fields.Many2One('party.party', 'Institution',
-        domain=[('is_institution', '=', "1")], select="1",
+        domain=[('is_institution', '=', "1")],
         help="Medical Center")
-    code = fields.Char('Code', select="2")
+    code = fields.Char('Code')
     extra_info = fields.Text('Extra Info')
 
 HospitalBuilding()
@@ -1525,12 +1574,12 @@ class HospitalUnit(ModelSQL, ModelView):
     "Hospital Unit"
     _description = __doc__
     _name = "gnuhealth.hospital.unit"
-    name = fields.Char('Name', select="1", required=True,
+    name = fields.Char('Name', required=True,
         help="Name of the unit, eg Neonatal, Intensive Care, ...")
     institution = fields.Many2One('party.party', 'Institution',
-        domain=[('is_institution', '=', "1")], select="1",
+        domain=[('is_institution', '=', "1")],
         help="Medical Center")
-    code = fields.Char('Code', select="2")
+    code = fields.Char('Code')
     extra_info = fields.Text('Extra Info')
 
 HospitalUnit()
@@ -1541,9 +1590,9 @@ class HospitalOR(ModelSQL, ModelView):
     _description = __doc__
     _name = "gnuhealth.hospital.or"
 
-    name = fields.Char('Name', required=True, select="1",
+    name = fields.Char('Name', required=True,
         help="Name of the Operating Room")
-    institution = fields.Many2One('party.party', 'Institution', select="1",
+    institution = fields.Many2One('party.party', 'Institution',
         domain=[('is_institution', '=', "1")], help="Medical Center")
     building = fields.Many2One('gnuhealth.hospital.building', 'Building',
         select="1")
@@ -1564,13 +1613,13 @@ class HospitalWard(ModelSQL, ModelView):
     _name = "gnuhealth.hospital.ward"
     _description = __doc__
 
-    name = fields.Char('Name', required=True, select="1",
+    name = fields.Char('Name', required=True,
      help="Ward / Room code")
-    institution = fields.Many2One('party.party', 'Institution', select="1",
+    institution = fields.Many2One('party.party', 'Institution',
         domain=[('is_institution', '=', "1")], help="Medical Center")
     building = fields.Many2One('gnuhealth.hospital.building', 'Building')
-    floor = fields.Integer('Floor Number', select="2")
-    unit = fields.Many2One('gnuhealth.hospital.unit', 'Unit', select="2")
+    floor = fields.Integer('Floor Number')
+    unit = fields.Many2One('gnuhealth.hospital.unit', 'Unit')
     private = fields.Boolean('Private',
         help="Check this option for private room")
     bio_hazard = fields.Boolean('Bio Hazard',
@@ -1586,9 +1635,9 @@ class HospitalWard(ModelSQL, ModelView):
     refrigerator = fields.Boolean('Refrigetator')
     microwave = fields.Boolean('Microwave')
     gender = fields.Selection((('men', 'Men Ward'), ('women', 'Women Ward'),
-        ('unisex', 'Unisex')), 'Gender', required=True,  select="2", sort=False)
+        ('unisex', 'Unisex')), 'Gender', required=True, sort=False)
     state = fields.Selection((('beds_available', 'Beds available'),
-        ('full', 'Full'), ('na', 'Not available')), 'Status',  select="2", sort=False)
+        ('full', 'Full'), ('na', 'Not available')), 'Status', sort=False)
     extra_info = fields.Text('Extra Info')
 
     def default_gender(self):
@@ -1605,19 +1654,19 @@ class HospitalBed(ModelSQL, ModelView):
     _description = __doc__
     _name = "gnuhealth.hospital.bed"
     name = fields.Many2One('product.product', 'Bed', domain=[('is_bed', '=', True)],
-     required=True, select="1",  help="Bed Number")
+     required=True,  help="Bed Number")
     ward = fields.Many2One('gnuhealth.hospital.ward',
-        'Ward',  select="2", help="Ward or room")
+        'Ward', help="Ward or room")
     bed_type = fields.Selection((('gatch', 'Gatch Bed'),
         ('electric', 'Electric'), ('stretcher', 'Stretcher'),
         ('low', 'Low Bed'), ('low_air_loss', 'Low Air Loss'),
         ('circo_electric', 'Circo Electric'),
-        ('clinitron', 'Clinitron')), 'Bed Type', required=True,  select="2", sort=False)
+        ('clinitron', 'Clinitron')), 'Bed Type', required=True, sort=False)
     telephone_number = fields.Char('Telephone Number',
         help="Telephone number / Extension")
     extra_info = fields.Text('Extra Info')
     state = fields.Selection((('free', 'Free'), ('reserved', 'Reserved'),
-     ('occupied', 'Occupied'), ('na', 'Not available')), 'Status',  select="2", sort=False)
+     ('occupied', 'Occupied'), ('na', 'Not available')), 'Status', sort=False)
 
     def default_bed_type(self):
         return 'gatch'
