@@ -1,7 +1,7 @@
 # -*- encoding: utf-8 -*-
 {
     'name': 'GNU Health : Genetics',
-    'version': '1.4.2',
+    'version': '1.4.3',
     'author': 'GNU Solidario',
     'email': 'health@gnusolidario.org',
     'website': 'http://health.gnu.org',
@@ -34,7 +34,7 @@ Incluye desórdenes genéticos y genes patológicos ("disease genes"), con una b
 
     'xml': [
         'health_genetics_view.xml',
-        'data/disease_genes.xml',
+        'data/disease_genes.xml','security/access_rights.xml'
     ],
     'active': False,
 }
