@@ -1,7 +1,7 @@
 # -*- encoding: utf-8 -*-
 {
     'name': 'GNU Health: Gynecology and Obstetrics',  
-    'version': '1.4.2',
+    'version': '1.4.3',
     'author': 'GNU Solidario',
     'email': 'health@gnusolidario.org',
     'website': 'http://health.gnu.org',
@@ -36,7 +36,7 @@ Este módulo incluye :
 ''',
 
     'xml': [
-        'health_gyneco_view.xml',
+        'health_gyneco_view.xml','security/access_rights.xml'
     ],
     'active': False,
 }
